==> tooltrims-1.2.0%2Bmc1.21.8-sources.jar: archives/tater/tooltrims/datagen/TrimPatternGenerator.java <==
package archives.tater.tooltrims.datagen;

import archives.tater.tooltrims.ToolTrimsPatterns;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricCodecDataProvider;
import net.minecraft.class_156;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7225.class_7874;
import net.minecraft.class_7784;
import net.minecraft.class_7891;
import net.minecraft.class_7924;
import net.minecraft.class_8056;
import java.util.concurrent.CompletableFuture;
import java.util.function.BiConsumer;

public class TrimPatternGenerator extends FabricCodecDataProvider<class_8056> {
    public TrimPatternGenerator(FabricDataOutput output, CompletableFuture<class_7874> registriesFuture) {
        super(output, registriesFuture, class_7784.class_7490.field_39367, "trim_pattern", class_8056.field_42014);
    }

    private static class_8056 of(class_2960 id) {
        return new class_8056(
                class_2960.method_60655("c", "n"),
                class_2561.method_43471(class_156.method_646("tool_trim_pattern", id)),
                false
        );
    }

    public static void boostrap(class_7891<class_8056> registry) {
        ToolTrimsPatterns.PATTERNS.forEach(pattern -> {
            registry.method_46838(pattern, of(pattern.method_29177()));
        });
    }

    @Override
    protected void configure(BiConsumer<class_2960, class_8056> biConsumer, class_7874 wrapperLookup) {
        ToolTrimsPatterns.PATTERNS.forEach(pattern ->
                biConsumer.accept(pattern.method_29177(), wrapperLookup.method_46762(class_7924.field_42082).method_46747(pattern).comp_349())
        );
    }

    @Override
    public String method_10321() {
        return "Trim Pattern Definitions";
    }

}

==> tooltrims-1.3.0%2Bmc1.21.1-sources.jar: archives/tater/tooltrims/datagen/TrimPatternGenerator.java <==
package archives.tater.tooltrims.datagen;

import archives.tater.tooltrims.ToolTrimsPatterns;
import archives.tater.tooltrims.item.ToolTrimsItems;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricCodecDataProvider;
import net.minecraft.class_156;
import net.minecraft.class_1792;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7225.class_7874;
import net.minecraft.class_7784;
import net.minecraft.class_7891;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import net.minecraft.class_8056;
import java.util.concurrent.CompletableFuture;
import java.util.function.BiConsumer;

public class TrimPatternGenerator extends FabricCodecDataProvider<class_8056> {
    public TrimPatternGenerator(FabricDataOutput output, CompletableFuture<class_7874> registriesFuture) {
        super(output, registriesFuture, class_7784.class_7490.field_39367, "trim_pattern", class_8056.field_42014);
    }

    private static class_8056 of(class_2960 id, class_1792 templateItem) {
        return new class_8056(
                class_2960.method_60655("c", "n"),
                class_7923.field_41178.method_47983(templateItem),
                class_2561.method_43471(class_156.method_646("tool_trim_pattern", id)),
                false
        );
    }

    public static void boostrap(class_7891<class_8056> registry) {
        ToolTrimsItems.SMITHING_TEMPLATES.forEach((pattern, template) -> {
            registry.method_46838(pattern, of(pattern.method_29177(), template));
        });
    }

    @Override
    protected void configure(BiConsumer<class_2960, class_8056> biConsumer, class_7874 wrapperLookup) {
        ToolTrimsPatterns.PATTERNS.forEach(pattern ->
                biConsumer.accept(pattern.method_29177(), wrapperLookup.method_46762(class_7924.field_42082).method_46747(pattern).comp_349())
        );
    }

    @Override
    public String method_10321() {
        return "Trim Pattern Definitions";
    }

}
